local CustomDecoration = ...

_PrefixAsset = "CUSTOM_DECORATION_V2"
_CommonWindowPrefix = "CUSTOM_WINDOW_V2"
_CommonDoorPrefix = "CUSTOM_DOOR_V2"
_CommonChurchPrefix = "CUSTOM_CHURCH_V2"

-- Register all stone gate set building parts and their properties
CustomDecoration:registerEnumValue ("BUILDING_PART_TYPE", "DECORATION")
CustomDecoration:dofile("scripts/compDecoration.lua")
CustomDecoration:dofile("scripts/decoration.lua")
CustomDecoration:dofile("scripts/compLeadWire.lua")
CustomDecoration:dofile("scripts/leadWire.lua")

-- Apply building asset processor
CustomDecoration:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

CustomDecoration:registerAssetId("models/core.fbx/Prefab/decoration/CoreBuildingPart", _PrefixAsset .. "_CORE_BUILDING_PREFAB")

-- Register the Core part
CustomDecoration:register({
	DataType = "BUILDING_PART",
	Id = _PrefixAsset .. "_CORE_BUILDING_PART",
	Name = _PrefixAsset .. "_CORE_BUILDING_NAME",
	Description = _PrefixAsset .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _PrefixAsset .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
})

function configureCommonMateriel(_color)
    return {
                SetName = _PrefixAsset .. "_" .. _color,
                MaterialList = {
                    _CommonWindowPrefix .. "_DECORATION_" .. _color .. "_MATERIAL",
                    _CommonWindowPrefix .. "_DECORATION_" .. _color .. "_MATERIAL",
                    _CommonWindowPrefix .. "_DECORATION_" .. _color .. "_MATERIAL"
                }
    }
end

CustomDecoration:register({
    DataType = "BUILDING",
    Id = _PrefixAsset .. "_MONUMENT",
    Name = _PrefixAsset .. "_MONUMENT_NAME",
    Description = _PrefixAsset .. "_MONUMENT_DESC",
    BuildingType = "DECORATION",
    AssetCoreBuildingPart = _PrefixAsset .. "_CORE_BUILDING_PART",
    BuildingPartSetList = {
		{
			Name = _PrefixAsset .. "_LEAD_WIRE_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_LEAD_WIRE_ROOT_PART"
                        }
                },
                {
			Name = _PrefixAsset .. "_STONE_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_SFENETRE_ROOT_PART",
		            _PrefixAsset .. "_LFENETRE_ROOT_PART",
		            _PrefixAsset .. "_PFENETRE_ROOT_PART",
		            _PrefixAsset .. "_STONE_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_ARROWSLIT_ROOT_PART",
		            _PrefixAsset .. "_BALCONY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_ROOT_PART",
		            _PrefixAsset .. "_CHIMNEY_B_ROOT_PART",
		            _PrefixAsset .. "_TURRET_ROOT_PART",
		            _PrefixAsset .. "_BUTTRESS_ROOT_PART",
		            _PrefixAsset .. "_DOOR_A_ROOT_PART",
		            _PrefixAsset .. "_DOOR_B_ROOT_PART"
                        }  
                },
                {
			Name = _PrefixAsset .. "_WOODEN_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _PrefixAsset .. "_WOODEN_DOOR_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_3_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_DOOR_4_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_3_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_7_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_8_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_WINDOW_9_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_POINTED_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_ROUND_WINDOW_ROOT_PART",
		            _PrefixAsset .. "_WOODEN_STAIRS_1_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LUCARNE_WHITE_ROOT_PART", -- whith white chalk wall
		            _PrefixAsset .. "_LARGE_LUCARNE_ROOT_PART",
		            _PrefixAsset .. "_LARGE_LUCARNE_WHITE_ROOT_PART"
                        }  
                },
                {
			Name = _PrefixAsset .. "_IRON_MONUMENT_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "_FINIAL1_ROOT_PART",
		            _PrefixAsset .. "_FINIAL2_ROOT_PART",
		            _PrefixAsset .. "_FINIAL3_ROOT_PART"
                        }   
                },
                {
			Name = _PrefixAsset .. "_STAINED_GLASS_PARTSETLIST_NAME",
	                BuildingPartList = {
                            _PrefixAsset .. "_STAINED_GLASS_WINDOW_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_2_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_3_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_4_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_8_ROOT_PART",
		            _PrefixAsset .. "_SPLENDOR_2_ROOT_PART",
		            _PrefixAsset .. "_P_STAINED_GLASS_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_1_ROOT_PART",
		            _PrefixAsset .. "_STAINED_GLASS_TALL_2_ROOT_PART"
                        }   
                }
    },
    MaterialSetList = {
            {
                SetName = _PrefixAsset .. "_RED_ROOF", -- default materials
                MaterialList = {
                    _CommonWindowPrefix .. "_STONE_WINDOW_RED_ROOF_MATERIAL",
                    _CommonWindowPrefix .. "_WOODEN_DOOR_RED_ROOF_MATERIAL",
                    _CommonWindowPrefix .. "_WOODEN_WINDOW_RED_ROOF_MATERIAL"
               }
            },
            configureCommonMateriel("BLUE_ROOF"),
            configureCommonMateriel("BROWN_ROOF"),
            configureCommonMateriel("GREY_ROOF"),
            configureCommonMateriel("GREY2_ROOF"),
            configureCommonMateriel("RED_WROOF"),
            configureCommonMateriel("BLUE_WROOF"),
            configureCommonMateriel("BROWN_WROOF"),
            configureCommonMateriel("YELLOW_WROOF"),
            configureCommonMateriel("GREEN_WROOF"),
            configureCommonMateriel("MANOR_WROOF"),
            configureCommonMateriel("MANOR2_WROOF"),
            configureCommonMateriel("BROWN_MONASTERY_ROOF"),
            configureCommonMateriel("BLUE_MONASTERY_ROOF"),
            configureCommonMateriel("PURPLE_MONASTERY_ROOF")
    },
    IsEditable = true
})

-- Adds Stained glasses to the vanilla Church
CustomDecoration:override({
    Id = "MONUMENT_CHURCH",
    BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = _CommonChurchPrefix .. "_ADDITION_NAME",
                	BuildingPartList = {
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_WINDOW_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_3_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_4_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_8_PART",
                            _CommonChurchPrefix .. "_DECORATION_SPLENDOR_2_PART",
                            _CommonChurchPrefix .. "_DECORATION_P_STAINED_GLASS_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_1_PART",
                            _CommonChurchPrefix .. "_DECORATION_STAINED_GLASS_TALL_2_PART"
                        }
                }
    }
})

